@@ -35,6 +35,16 @@ def parse_gracefully(parser, argv):
 
 
 def parse(argv, collection=None):
+    """
+    Parse ``argv`` list-of-strings into useful core & per-task structures.
+
+    :returns:
+        Three-tuple of ``args`` (core, non-task `.Argument` objects), ``collection``
+        (compiled `.Collection` of tasks, using defaults or core arguments
+        affecting collection generation) and ``tasks`` (a list of
+        `~.parser.context.Context` objects representing the requested task
+        executions).
+    """
     # Initial/core parsing (core options can affect the rest of the parsing)
     initial_context = ParserContext(args=(
         # TODO: make '--collection' a list-building arg, not a string
