@@ -1,5 +1,6 @@
 """
-Task definition & manipulation
+This module contains the core `.Task` class & convenience decorators used to
+generate new tasks.
 """
 import inspect
 import types
@@ -69,6 +70,9 @@ class Task(object):
         Returns two-tuple:
 
         * First item is list of arg names, in order defined.
+
+            * I.e. we *cannot* simply use a dict's ``keys()`` method here.
+
         * Second item is dict mapping arg names to default values or
           task.NO_DEFAULT (i.e. an 'empty' value distinct from None).
         """
@@ -99,7 +103,12 @@ class Task(object):
         return positional
 
     def arg_opts(self, name, default, taken_names):
-        # Argument name(s)
+        opts = {}
+        # Argument name(s) (replace w/ dashed version if underscores present,
+        # and move the underscored version to be the attr_name instead.)
+        if '_' in name:
+            opts['attr_name'] = name
+            name = name.replace('_', '-')
         names = [name]
         if self.auto_shortflags:
             # Must know what short names are available
@@ -107,7 +116,7 @@ class Task(object):
                 if not (char == name or char in taken_names):
                     names.append(char)
                     break
-        opts = {'names': names}
+        opts['names'] = names
         # Handle default value & kind if possible
         if default not in (None, NO_DEFAULT):
             # TODO: allow setting 'kind' explicitly.
@@ -162,8 +171,8 @@ def task(*args, **kwargs):
     parenthese'd form:
 
     * ``contextualized``: Hints to callers (especially the CLI) that this task
-      expects to be given a `.Context` object as its first argument when
-      called.
+      expects to be given a `~invoke.context.Context` object as its first
+      argument when called.
     * ``aliases``: Specify one or more aliases for this task, allowing it to be
       invoked as multiple different names. For example, a task named ``mytask``
       with a simple ``@task`` wrapper may only be invoked as ``"mytask"``.
@@ -177,8 +186,8 @@ def task(*args, **kwargs):
     * ``default``: Boolean option specifying whether this task should be its
       collection's default task (i.e. called if the collection's own name is
       given.)
-    * ``auto_shortflags``: Whether or not to :ref:`automatically create short
-      flags <automatic-shortflags>` from task options; defaults to True.
+    * ``auto_shortflags``: Whether or not to automatically create short
+      flags from task options; defaults to True.
     * ``help``: Dict mapping argument names to their help strings. Will be
       displayed in ``--help`` output.
     * ``pre``: List of task names, for tasks that should get run prior to the
@@ -227,5 +236,10 @@ def task(*args, **kwargs):
 
 
 def ctask(*args, **kwargs):
+    """
+    Wrapper for `.task` which sets ``contextualized=True`` by default.
+
+    Please see `.task` for documentation.
+    """
     kwargs.setdefault('contextualized', True)
     return task(*args, **kwargs)
