@@ -229,3 +229,12 @@ class Task_(Spec):
             def mytask(ctx):
                 pass
             eq_(len(mytask.get_arguments()), 0)
+
+        def underscores_become_dashes(self):
+            @task
+            def mytask(longer_arg):
+                pass
+            arg = mytask.get_arguments()[0]
+            eq_(arg.names, ('longer-arg', 'l'))
+            eq_(arg.attr_name, 'longer_arg')
+            eq_(arg.name, 'longer_arg')
